@@ -16,17 +16,16 @@ sub register {
 
   my @helpers = (
     qw(csrf_field form_for hidden_field javascript label_for link_to),
-    qw(password_field select_field stylesheet submit_button tag_with_error),
-    qw(text_area)
+    qw(select_field stylesheet submit_button tag_with_error text_area)
   );
   $app->helper($_ => __PACKAGE__->can("_$_")) for @helpers;
 
   $app->helper(check_box =>
       sub { _input(shift, shift, value => shift, @_, type => 'checkbox') });
-  $app->helper(file_field =>
-      sub { shift; _tag('input', name => shift, @_, type => 'file') });
+  $app->helper(file_field => sub { _empty_field('file', @_) });
   $app->helper(image => sub { _tag('img', src => shift->url_for(shift), @_) });
   $app->helper(input_tag => sub { _input(@_) });
+  $app->helper(password_field => sub { _empty_field('password', @_) });
   $app->helper(radio_button =>
       sub { _input(shift, shift, value => shift, @_, type => 'radio') });
 
@@ -39,6 +38,11 @@ sub _csrf_field {
   return _hidden_field($c, csrf_token => $c->helpers->csrf_token, @_);
 }
 
+sub _empty_field {
+  my ($type, $c, $name) = (shift, shift, shift);
+  return _validation($c, $name, 'input', name => $name, @_, type => $type);
+}
+
 sub _form_for {
   my ($c, @url) = (shift, shift);
   push @url, shift if ref $_[0] eq 'HASH';
@@ -71,6 +75,7 @@ sub _input {
     my $value = $attrs{value} // '';
     if ($type eq 'checkbox' || $type eq 'radio') {
       $attrs{value} = $value;
+      delete $attrs{checked} if @values;
       $attrs{checked} = undef if grep { $_ eq $value } @values;
     }
 
@@ -113,16 +118,13 @@ sub _link_to {
 
 sub _option {
   my ($values, $pair) = @_;
-  $pair = [$pair => $pair] unless ref $pair eq 'ARRAY';
-  my %attrs = (value => $pair->[1]);
-  $attrs{selected} = undef if exists $values->{$pair->[1]};
-  return _tag('option', %attrs, @$pair[2 .. $#$pair], $pair->[0]);
-}
 
-sub _password_field {
-  my ($c, $name) = (shift, shift);
-  return _validation($c, $name, 'input', name => $name, @_,
-    type => 'password');
+  $pair = [$pair => $pair] unless ref $pair eq 'ARRAY';
+  my %attrs = (value => $pair->[1], @$pair[2 .. $#$pair]);
+  delete $attrs{selected} if keys %$values;
+  $attrs{selected} = undef if $values->{$pair->[1]};
+
+  return _tag('option', %attrs, $pair->[0]);
 }
 
 sub _select_field {
@@ -215,7 +217,7 @@ Mojolicious::Plugin::TagHelpers - Tag helpers plugin
 =head1 SYNOPSIS
 
   # Mojolicious
-  $self->plugin('TagHelpers');
+  $app->plugin('TagHelpers');
 
   # Mojolicious::Lite
   plugin 'TagHelpers';
@@ -254,13 +256,13 @@ L<Mojolicious::Plugin::TagHelpers> implements the following helpers.
 =head2 check_box
 
   %= check_box employed => 1
-  %= check_box employed => 1, disabled => 'disabled'
+  %= check_box employed => 1, checked => undef, id => 'foo'
 
 Generate C<input> tag of type C<checkbox>. Previous input values will
 automatically get picked up and shown as default.
 
   <input name="employed" type="checkbox" value="1">
-  <input disabled="disabled" name="employed" type="checkbox" value="1">
+  <input checked id="foo" name="employed" type="checkbox" value="1">
 
 =head2 color_field
 
@@ -515,13 +517,13 @@ Generate C<input> tag of type C<password>.
 =head2 radio_button
 
   %= radio_button country => 'germany'
-  %= radio_button country => 'germany', id => 'foo'
+  %= radio_button country => 'germany', checked => undef, id => 'foo'
 
 Generate C<input> tag of type C<radio>. Previous input values will
 automatically get picked up and shown as default.
 
   <input name="country" type="radio" value="germany">
-  <input id="foo" name="country" type="radio" value="germany">
+  <input checked id="foo" name="country" type="radio" value="germany">
 
 =head2 range_field
 
@@ -553,7 +555,7 @@ automatically get picked up and shown as default.
 
   %= select_field country => [qw(de en)]
   %= select_field country => [[Germany => 'de'], 'en'], id => 'eu'
-  %= select_field country => [[Germany => 'de', disabled => 'disabled'], 'en']
+  %= select_field country => [[Germany => 'de', selected => 'selected'], 'en']
   %= select_field country => [c(EU => [[Germany => 'de'], 'en'], id => 'eu')]
   %= select_field country => [c(EU => [qw(de en)]), c(Asia => [qw(cn jp)])]
 
@@ -570,7 +572,7 @@ get picked up and shown as default.
     <option value="en">en</option>
   </select>
   <select name="country">
-    <option disabled="disabled" value="de">Germany</option>
+    <option selected="selected" value="de">Germany</option>
     <option value="en">en</option>
   </select>
   <select name="country">
